"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var React = require("react");
var react_table_plain_1 = require("@dccs/react-table-plain");
var DataGridStateContext_1 = require("./DataGridStateContext");
function DataGridPlain(props) {
    // Internal state...if there is no DataGridStateProvider.
    var _a = React.useState(props.initialRowsPerPage || 10), rowsPerPage = _a[0], setRowsPerPage = _a[1];
    var _b = React.useState(0), page = _b[0], setPage = _b[1];
    var _c = React.useState(0), total = _c[0], setTotal = _c[1];
    var _d = React.useState(props.initialOrderBy), orderBy = _d[0], setOrderBy = _d[1];
    var _e = React.useState(), sort = _e[0], setSort = _e[1];
    var _f = React.useState(), filter = _f[0], setFilter = _f[1];
    // Do we have a custom context,...
    var state = React.useContext(DataGridStateContext_1.DataGridState) || {
        rowsPerPage: rowsPerPage,
        setRowsPerPage: setRowsPerPage,
        page: page,
        setPage: setPage,
        total: total,
        setTotal: setTotal,
        orderBy: orderBy,
        setOrderBy: setOrderBy,
        sort: sort,
        setSort: setSort,
        filter: filter,
        setFilter: setFilter,
        reload: function () {
            throw new Error("No supported in DateGridPlain, only in DataGridStateProvider.");
        }
    };
    var _g = React.useState([]), data = _g[0], setData = _g[1];
    var _h = React.useState(false), loading = _h[0], setLoading = _h[1];
    var _j = React.useState(false), error = _j[0], setError = _j[1];
    React.useEffect(function () {
        setLoading(true);
        setError(false);
        props
            .onLoadData(state.page + 1, state.rowsPerPage, state.orderBy, state.sort, state.filter)
            .then(function (_a) {
            var d = _a.data, t = _a.total;
            state.setTotal(t);
            setData(d);
            setLoading(false);
        })
            .catch(function () {
            setLoading(false);
            setError(true);
        });
    }, [
        state.rowsPerPage,
        state.page,
        state.orderBy,
        state.sort === "desc",
        state.filter,
        props
    ]);
    function load() {
        setLoading(true);
        setError(false);
        props
            .onLoadData(state.page + 1, state.rowsPerPage, state.orderBy, state.sort, state.filter)
            .then(function (_a) {
            var d = _a.data, t = _a.total;
            state.setTotal(t);
            setData(d);
            setLoading(false);
        })
            .catch(function () {
            setLoading(false);
            setError(true);
        });
    }
    function handleChangePage(p) {
        state.setPage(p);
    }
    function handleChangeRowsPerPage(rows) {
        state.setRowsPerPage(rows);
    }
    function handleChangeOrderBy(ob) {
        var s;
        if (state.orderBy && state.orderBy === ob) {
            s = state.sort === "desc" ? "asc" : "desc";
        }
        state.setOrderBy(ob);
        state.setSort(s);
    }
    function handleChangeFilter(ob, value) {
        var _a;
        state.setFilter(__assign({}, state.filter, (_a = {}, _a[ob] = value, _a)));
    }
    function renderTable() {
        var ps = {
            data: data,
            colDef: props.colDef,
            orderBy: state.orderBy,
            sort: state.sort,
            onChangeOrderBy: handleChangeOrderBy,
            onChangeFilter: handleChangeFilter,
            onRowClick: props.onRowClick,
            subComponent: props.subComponent
        };
        if (props.renderTable != null) {
            return props.renderTable(ps);
        }
        return React.createElement(react_table_plain_1.TablePlain, __assign({}, ps));
    }
    function renderLoading() {
        if (props.renderLoading != null) {
            return props.renderLoading();
        }
        return React.createElement("h5", null, "Loading...");
    }
    function renderError() {
        if (props.renderError != null) {
            return props.renderError(load);
        }
        return (React.createElement("p", { style: { width: "100%", background: "red", padding: 16 } },
            React.createElement("p", null, "Die Daten konnten nicht geladen werden."),
            React.createElement("p", null,
                React.createElement("button", { onClick: function () { return load(); } }, "Neu laden"))));
    }
    function renderPaging() {
        if (props.renderPaging != null) {
            return props.renderPaging(__assign({}, state, { handleChangePage: handleChangePage,
                handleChangeRowsPerPage: handleChangeRowsPerPage }));
        }
        return React.createElement("strong", null, "No paging available right now. Check back later...");
    }
    if (error) {
        return renderError();
    }
    return (React.createElement("div", { style: { position: "relative", overflowX: "auto", width: "100%" } },
        loading && renderLoading(),
        renderTable(),
        props.disablePaging !== true && renderPaging()));
}
exports.DataGridPlain = DataGridPlain;
